package com.gmei.data.dqmp.pool;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.util.Properties;

public class JdbcConnectPool {
	private static Properties prop;
	private static int requestCount = 0;
	private static final Logger logger = LoggerFactory.getLogger(JdbcConnectPool.class);
	static {
		prop = getProperties("jdbc.properties");
		try {
			Class.forName(prop.getProperty("driverClassName"));
		} catch (ClassNotFoundException e) {
			e.printStackTrace();
		}
	}

	public static Connection getConnection() {
		logger.info("requestCount : {}",++requestCount);
		return createConnect();
	}

	/**
	 * 创建连接
	 * 
	 * @return
	 */
	private static Connection createConnect() {
		Connection conn = null;
		try {
			conn = DriverManager.getConnection(
					prop.getProperty("url"),
					prop.getProperty("username"),
					prop.getProperty("password"));
		} catch (SQLException e) {
			e.printStackTrace();
		}
		return conn;
	}

	/**
	 * 释放连接
	 */
	public static void releaseConnection(Connection conn) {
		try{
			conn.close();
		}catch (Exception e){
			conn = null;
			e.printStackTrace();
		}
	}

	/**
	 * 获取属性文件对象
	 * 
	 * @param path
	 * @return
	 */
	private static Properties getProperties(String path) {
		Properties properties = new Properties();
		try {
			InputStream inputStream = JdbcConnectPool.class.getClassLoader().getResourceAsStream(path);
			properties.load(inputStream);
			inputStream.close();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		return properties;
	}
}
